==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/NetworkRuleSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.NetworkRuleSetArgs.builder
import com.pulumi.azurenative.storage.kotlin.enums.Bypass
import com.pulumi.azurenative.storage.kotlin.enums.DefaultAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Network rule set
 * @property bypass Specifies whether traffic is bypassed for Logging/Metrics/AzureServices. Possible values are any combination of Logging|Metrics|AzureServices (For example, "Logging, Metrics"), or None to bypass none of those traffics.
 * @property defaultAction Specifies the default action of allow or deny when no other rules match.
 * @property ipRules Sets the IP ACL rules
 * @property resourceAccessRules Sets the resource access rules
 * @property virtualNetworkRules Sets the virtual network rules
 */
public data class NetworkRuleSetArgs(
    public val bypass: Output<Either<String, Bypass>>? = null,
    public val defaultAction: Output<DefaultAction>,
    public val ipRules: Output<List<IPRuleArgs>>? = null,
    public val resourceAccessRules: Output<List<ResourceAccessRuleArgs>>? = null,
    public val virtualNetworkRules: Output<List<VirtualNetworkRuleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.NetworkRuleSetArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.NetworkRuleSetArgs =
        com.pulumi.azurenative.storage.inputs.NetworkRuleSetArgs.builder()
            .bypass(
                bypass?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .defaultAction(defaultAction.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .ipRules(
                ipRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .resourceAccessRules(
                resourceAccessRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .virtualNetworkRules(
                virtualNetworkRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [NetworkRuleSetArgs].
 */
@PulumiTagMarker
public class NetworkRuleSetArgsBuilder internal constructor() {
    private var bypass: Output<Either<String, Bypass>>? = null

    private var defaultAction: Output<DefaultAction>? = null

    private var ipRules: Output<List<IPRuleArgs>>? = null

    private var resourceAccessRules: Output<List<ResourceAccessRuleArgs>>? = null

    private var virtualNetworkRules: Output<List<VirtualNetworkRuleArgs>>? = null

    /**
     * @param value Specifies whether traffic is bypassed for Logging/Metrics/AzureServices. Possible values are any combination of Logging|Metrics|AzureServices (For example, "Logging, Metrics"), or None to bypass none of those traffics.
     */
    @JvmName("rvxkhenvyswbirar")
    public suspend fun bypass(`value`: Output<Either<String, Bypass>>) {
        this.bypass = value
    }

    /**
     * @param value Specifies the default action of allow or deny when no other rules match.
     */
    @JvmName("pjegiqhcqxavcchf")
    public suspend fun defaultAction(`value`: Output<DefaultAction>) {
        this.defaultAction = value
    }

    /**
     * @param value Sets the IP ACL rules
     */
    @JvmName("idvloenpprfhwnlc")
    public suspend fun ipRules(`value`: Output<List<IPRuleArgs>>) {
        this.ipRules = value
    }

    @JvmName("vumxlkqqvrswqpfn")
    public suspend fun ipRules(vararg values: Output<IPRuleArgs>) {
        this.ipRules = Output.all(values.asList())
    }

    /**
     * @param values Sets the IP ACL rules
     */
    @JvmName("jgpmupmuasbbrchx")
    public suspend fun ipRules(values: List<Output<IPRuleArgs>>) {
        this.ipRules = Output.all(values)
    }

    /**
     * @param value Sets the resource access rules
     */
    @JvmName("yhvjwpjwjbadgraj")
    public suspend fun resourceAccessRules(`value`: Output<List<ResourceAccessRuleArgs>>) {
        this.resourceAccessRules = value
    }

    @JvmName("wxihbayxyapcdyfp")
    public suspend fun resourceAccessRules(vararg values: Output<ResourceAccessRuleArgs>) {
        this.resourceAccessRules = Output.all(values.asList())
    }

    /**
     * @param values Sets the resource access rules
     */
    @JvmName("etlwkhwpburebitb")
    public suspend fun resourceAccessRules(values: List<Output<ResourceAccessRuleArgs>>) {
        this.resourceAccessRules = Output.all(values)
    }

    /**
     * @param value Sets the virtual network rules
     */
    @JvmName("ipcwunxijanwpvck")
    public suspend fun virtualNetworkRules(`value`: Output<List<VirtualNetworkRuleArgs>>) {
        this.virtualNetworkRules = value
    }

    @JvmName("epmakbewhyvoivkb")
    public suspend fun virtualNetworkRules(vararg values: Output<VirtualNetworkRuleArgs>) {
        this.virtualNetworkRules = Output.all(values.asList())
    }

    /**
     * @param values Sets the virtual network rules
     */
    @JvmName("ovtmwjgqqhfpgyro")
    public suspend fun virtualNetworkRules(values: List<Output<VirtualNetworkRuleArgs>>) {
        this.virtualNetworkRules = Output.all(values)
    }

    /**
     * @param value Specifies whether traffic is bypassed for Logging/Metrics/AzureServices. Possible values are any combination of Logging|Metrics|AzureServices (For example, "Logging, Metrics"), or None to bypass none of those traffics.
     */
    @JvmName("lurbngmiuwkptsxs")
    public suspend fun bypass(`value`: Either<String, Bypass>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bypass = mapped
    }

    /**
     * @param value Specifies whether traffic is bypassed for Logging/Metrics/AzureServices. Possible values are any combination of Logging|Metrics|AzureServices (For example, "Logging, Metrics"), or None to bypass none of those traffics.
     */
    @JvmName("nsrcuyqsjxpssalg")
    public fun bypass(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Bypass>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.bypass = mapped
    }

    /**
     * @param value Specifies whether traffic is bypassed for Logging/Metrics/AzureServices. Possible values are any combination of Logging|Metrics|AzureServices (For example, "Logging, Metrics"), or None to bypass none of those traffics.
     */
    @JvmName("llosaoolivejpkwm")
    public fun bypass(`value`: Bypass) {
        val toBeMapped = Either.ofRight<String, Bypass>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.bypass = mapped
    }

    /**
     * @param value Specifies the default action of allow or deny when no other rules match.
     */
    @JvmName("gtlfwhvmtisfctgs")
    public suspend fun defaultAction(`value`: DefaultAction) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Sets the IP ACL rules
     */
    @JvmName("yfhanersxloqxfkv")
    public suspend fun ipRules(`value`: List<IPRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param argument Sets the IP ACL rules
     */
    @JvmName("gubcbddjbyexomsr")
    public suspend fun ipRules(argument: List<suspend IPRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IPRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument Sets the IP ACL rules
     */
    @JvmName("msaseqsrdjlkhtgt")
    public suspend fun ipRules(vararg argument: suspend IPRuleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IPRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument Sets the IP ACL rules
     */
    @JvmName("nlweengrbmfjutkd")
    public suspend fun ipRules(argument: suspend IPRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IPRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param values Sets the IP ACL rules
     */
    @JvmName("edijvnnnoxmnqdag")
    public suspend fun ipRules(vararg values: IPRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param value Sets the resource access rules
     */
    @JvmName("vaftwuhsdgtpavks")
    public suspend fun resourceAccessRules(`value`: List<ResourceAccessRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessRules = mapped
    }

    /**
     * @param argument Sets the resource access rules
     */
    @JvmName("urvnydxjumhcwskk")
    public suspend
    fun resourceAccessRules(argument: List<suspend ResourceAccessRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceAccessRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceAccessRules = mapped
    }

    /**
     * @param argument Sets the resource access rules
     */
    @JvmName("hlkuneggurkoxfmm")
    public suspend fun resourceAccessRules(
        vararg
        argument: suspend ResourceAccessRuleArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceAccessRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceAccessRules = mapped
    }

    /**
     * @param argument Sets the resource access rules
     */
    @JvmName("mgfcjgmjuilhsoil")
    public suspend
    fun resourceAccessRules(argument: suspend ResourceAccessRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceAccessRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.resourceAccessRules = mapped
    }

    /**
     * @param values Sets the resource access rules
     */
    @JvmName("ralycjyyrjxiyaop")
    public suspend fun resourceAccessRules(vararg values: ResourceAccessRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceAccessRules = mapped
    }

    /**
     * @param value Sets the virtual network rules
     */
    @JvmName("lyukxxmfqwitburd")
    public suspend fun virtualNetworkRules(`value`: List<VirtualNetworkRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.virtualNetworkRules = mapped
    }

    /**
     * @param argument Sets the virtual network rules
     */
    @JvmName("aoovlgplbnvmabqh")
    public suspend
    fun virtualNetworkRules(argument: List<suspend VirtualNetworkRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.virtualNetworkRules = mapped
    }

    /**
     * @param argument Sets the virtual network rules
     */
    @JvmName("muhsfklgmkuvepnx")
    public suspend fun virtualNetworkRules(
        vararg
        argument: suspend VirtualNetworkRuleArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.virtualNetworkRules = mapped
    }

    /**
     * @param argument Sets the virtual network rules
     */
    @JvmName("txpmpauktafeelof")
    public suspend
    fun virtualNetworkRules(argument: suspend VirtualNetworkRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VirtualNetworkRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.virtualNetworkRules = mapped
    }

    /**
     * @param values Sets the virtual network rules
     */
    @JvmName("neuceghgqxseihmj")
    public suspend fun virtualNetworkRules(vararg values: VirtualNetworkRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNetworkRules = mapped
    }

    internal fun build(): NetworkRuleSetArgs = NetworkRuleSetArgs(
        bypass = bypass,
        defaultAction = defaultAction ?: throw PulumiNullFieldException("defaultAction"),
        ipRules = ipRules,
        resourceAccessRules = resourceAccessRules,
        virtualNetworkRules = virtualNetworkRules,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/NetworkRuleSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.NetworkRuleSetArgs.builder
import com.pulumi.azurenative.storage.kotlin.enums.Bypass
import com.pulumi.azurenative.storage.kotlin.enums.DefaultAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Network rule set
 * @property bypass Specifies whether traffic is bypassed for Logging/Metrics/AzureServices. Possible values are any combination of Logging|Metrics|AzureServices (For example, "Logging, Metrics"), or None to bypass none of those traffics.
 * @property defaultAction Specifies the default action of allow or deny when no other rules match.
 * @property ipRules Sets the IP ACL rules
 * @property resourceAccessRules Sets the resource access rules
 * @property virtualNetworkRules Sets the virtual network rules
 */
public data class NetworkRuleSetArgs(
    public val bypass: Output<Either<String, Bypass>>? = null,
    public val defaultAction: Output<DefaultAction>,
    public val ipRules: Output<List<IPRuleArgs>>? = null,
    public val resourceAccessRules: Output<List<ResourceAccessRuleArgs>>? = null,
    public val virtualNetworkRules: Output<List<VirtualNetworkRuleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.NetworkRuleSetArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.NetworkRuleSetArgs =
        com.pulumi.azurenative.storage.inputs.NetworkRuleSetArgs.builder()
            .bypass(
                bypass?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .defaultAction(defaultAction.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .ipRules(
                ipRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .resourceAccessRules(
                resourceAccessRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .virtualNetworkRules(
                virtualNetworkRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [NetworkRuleSetArgs].
 */
@PulumiTagMarker
public class NetworkRuleSetArgsBuilder internal constructor() {
    private var bypass: Output<Either<String, Bypass>>? = null

    private var defaultAction: Output<DefaultAction>? = null

    private var ipRules: Output<List<IPRuleArgs>>? = null

    private var resourceAccessRules: Output<List<ResourceAccessRuleArgs>>? = null

    private var virtualNetworkRules: Output<List<VirtualNetworkRuleArgs>>? = null

    /**
     * @param value Specifies whether traffic is bypassed for Logging/Metrics/AzureServices. Possible values are any combination of Logging|Metrics|AzureServices (For example, "Logging, Metrics"), or None to bypass none of those traffics.
     */
    @JvmName("ejbtndxcedtyedee")
    public suspend fun bypass(`value`: Output<Either<String, Bypass>>) {
        this.bypass = value
    }

    /**
     * @param value Specifies the default action of allow or deny when no other rules match.
     */
    @JvmName("xawwjhcbiopwrnen")
    public suspend fun defaultAction(`value`: Output<DefaultAction>) {
        this.defaultAction = value
    }

    /**
     * @param value Sets the IP ACL rules
     */
    @JvmName("oivvpnnplpktwwur")
    public suspend fun ipRules(`value`: Output<List<IPRuleArgs>>) {
        this.ipRules = value
    }

    @JvmName("wxgcqqkoxirhuopd")
    public suspend fun ipRules(vararg values: Output<IPRuleArgs>) {
        this.ipRules = Output.all(values.asList())
    }

    /**
     * @param values Sets the IP ACL rules
     */
    @JvmName("mtjfcokrwkigaqlv")
    public suspend fun ipRules(values: List<Output<IPRuleArgs>>) {
        this.ipRules = Output.all(values)
    }

    /**
     * @param value Sets the resource access rules
     */
    @JvmName("tomhoyyrvmqgdqcg")
    public suspend fun resourceAccessRules(`value`: Output<List<ResourceAccessRuleArgs>>) {
        this.resourceAccessRules = value
    }

    @JvmName("ivlafixxynfjtilu")
    public suspend fun resourceAccessRules(vararg values: Output<ResourceAccessRuleArgs>) {
        this.resourceAccessRules = Output.all(values.asList())
    }

    /**
     * @param values Sets the resource access rules
     */
    @JvmName("nriiojlfnxlibudf")
    public suspend fun resourceAccessRules(values: List<Output<ResourceAccessRuleArgs>>) {
        this.resourceAccessRules = Output.all(values)
    }

    /**
     * @param value Sets the virtual network rules
     */
    @JvmName("yicrwavolbdjmyik")
    public suspend fun virtualNetworkRules(`value`: Output<List<VirtualNetworkRuleArgs>>) {
        this.virtualNetworkRules = value
    }

    @JvmName("ewxpqsuagogywltd")
    public suspend fun virtualNetworkRules(vararg values: Output<VirtualNetworkRuleArgs>) {
        this.virtualNetworkRules = Output.all(values.asList())
    }

    /**
     * @param values Sets the virtual network rules
     */
    @JvmName("sxpdjltajbicbvmn")
    public suspend fun virtualNetworkRules(values: List<Output<VirtualNetworkRuleArgs>>) {
        this.virtualNetworkRules = Output.all(values)
    }

    /**
     * @param value Specifies whether traffic is bypassed for Logging/Metrics/AzureServices. Possible values are any combination of Logging|Metrics|AzureServices (For example, "Logging, Metrics"), or None to bypass none of those traffics.
     */
    @JvmName("mclkbjgmluytswts")
    public suspend fun bypass(`value`: Either<String, Bypass>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bypass = mapped
    }

    /**
     * @param value Specifies whether traffic is bypassed for Logging/Metrics/AzureServices. Possible values are any combination of Logging|Metrics|AzureServices (For example, "Logging, Metrics"), or None to bypass none of those traffics.
     */
    @JvmName("ofoahicbxiqhgucf")
    public fun bypass(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Bypass>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.bypass = mapped
    }

    /**
     * @param value Specifies whether traffic is bypassed for Logging/Metrics/AzureServices. Possible values are any combination of Logging|Metrics|AzureServices (For example, "Logging, Metrics"), or None to bypass none of those traffics.
     */
    @JvmName("tuyeyntrvglhopjy")
    public fun bypass(`value`: Bypass) {
        val toBeMapped = Either.ofRight<String, Bypass>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.bypass = mapped
    }

    /**
     * @param value Specifies the default action of allow or deny when no other rules match.
     */
    @JvmName("kvocomycaknyoqme")
    public suspend fun defaultAction(`value`: DefaultAction) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Sets the IP ACL rules
     */
    @JvmName("ypnwhkunalrmkqrv")
    public suspend fun ipRules(`value`: List<IPRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param argument Sets the IP ACL rules
     */
    @JvmName("puqccbbpukuommvc")
    public suspend fun ipRules(argument: List<suspend IPRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IPRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument Sets the IP ACL rules
     */
    @JvmName("rixwoqbhbsyrymyy")
    public suspend fun ipRules(vararg argument: suspend IPRuleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IPRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument Sets the IP ACL rules
     */
    @JvmName("ljmteeddmdxctdpx")
    public suspend fun ipRules(argument: suspend IPRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IPRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param values Sets the IP ACL rules
     */
    @JvmName("qashqylvtietdywy")
    public suspend fun ipRules(vararg values: IPRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param value Sets the resource access rules
     */
    @JvmName("gdhyymqlxdhtwaga")
    public suspend fun resourceAccessRules(`value`: List<ResourceAccessRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessRules = mapped
    }

    /**
     * @param argument Sets the resource access rules
     */
    @JvmName("cxhcqcahxhcolloq")
    public suspend
    fun resourceAccessRules(argument: List<suspend ResourceAccessRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceAccessRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceAccessRules = mapped
    }

    /**
     * @param argument Sets the resource access rules
     */
    @JvmName("cvyqiakftrykjrqv")
    public suspend fun resourceAccessRules(
        vararg
        argument: suspend ResourceAccessRuleArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceAccessRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceAccessRules = mapped
    }

    /**
     * @param argument Sets the resource access rules
     */
    @JvmName("qluojdardxonvcvy")
    public suspend
    fun resourceAccessRules(argument: suspend ResourceAccessRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceAccessRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.resourceAccessRules = mapped
    }

    /**
     * @param values Sets the resource access rules
     */
    @JvmName("cejlqhneroabkgtk")
    public suspend fun resourceAccessRules(vararg values: ResourceAccessRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceAccessRules = mapped
    }

    /**
     * @param value Sets the virtual network rules
     */
    @JvmName("rsmyljolerdpojuh")
    public suspend fun virtualNetworkRules(`value`: List<VirtualNetworkRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.virtualNetworkRules = mapped
    }

    /**
     * @param argument Sets the virtual network rules
     */
    @JvmName("ibektnxebybnhuge")
    public suspend
    fun virtualNetworkRules(argument: List<suspend VirtualNetworkRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.virtualNetworkRules = mapped
    }

    /**
     * @param argument Sets the virtual network rules
     */
    @JvmName("iypybpdenahcvwsu")
    public suspend fun virtualNetworkRules(
        vararg
        argument: suspend VirtualNetworkRuleArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.virtualNetworkRules = mapped
    }

    /**
     * @param argument Sets the virtual network rules
     */
    @JvmName("ftbibtcnankaonce")
    public suspend
    fun virtualNetworkRules(argument: suspend VirtualNetworkRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VirtualNetworkRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.virtualNetworkRules = mapped
    }

    /**
     * @param values Sets the virtual network rules
     */
    @JvmName("ncdqsfhwwsybqlpg")
    public suspend fun virtualNetworkRules(vararg values: VirtualNetworkRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNetworkRules = mapped
    }

    internal fun build(): NetworkRuleSetArgs = NetworkRuleSetArgs(
        bypass = bypass,
        defaultAction = defaultAction ?: throw PulumiNullFieldException("defaultAction"),
        ipRules = ipRules,
        resourceAccessRules = resourceAccessRules,
        virtualNetworkRules = virtualNetworkRules,
    )
}
